<?php
/*------------------------------------------------------------------------
# News Show SP1 - News display module by JoomShaper.com
# ------------------------------------------------------------------------
# author    JoomShaper http://www.joomshaper.com
# copyright Copyright (C) 2010 JoomShaper.com. All Rights Reserved.
# @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
# Websites: http://www.joomshaper.com - http://www.joomxpert.com
-------------------------------------------------------------------------*/

// no direct access
defined('_JEXEC') or die('Restricted access');

require_once JPATH_SITE.'/components/com_content/helpers/route.php';

jimport('joomla.application.component.model');
JModel::addIncludePath(JPATH_SITE.'/components/com_content/models');

abstract class modNSSP1Helper
{

	static function getList($params,$uniqid){
		
		$app	= JFactory::getApplication();
		$db		= JFactory::getDbo();

		// Get an instance of the generic articles model
		$model = JModel::getInstance('Articles', 'ContentModel', array('ignore_request' => true));

		// Set application parameters in model
		$appParams = JFactory::getApplication()->getParams();
		$model->setState('params', $appParams);

		// Set the filters based on the module params
		$model->setState('list.start', 0);

		$article_count	= $params->get('article_count',3);
		$link_count		= $params->get('link_count',3);
		$links		    = $params->get('links',1)==1 ? true : false;
		$count 			= $links ? $article_count + $link_count : $article_count;				
		$thumbratio		= $params->get('thumbratio', 1) ? true : false;
		$thumbwidth		= trim($params->get('thumbwidth', 50));
		$thumbheight	= trim($params->get('thumbheight', 50));
		
		$model->setState('list.limit', (int) $count);
		
		$model->setState('filter.published', 1);

		// User filter
		$userId = JFactory::getUser()->get('id');
		switch ($params->get('user_id'))
		{
			case 'by_me':
				$model->setState('filter.author_id', (int) $userId);
				break;
			case 'not_me':
				$model->setState('filter.author_id', $userId);
				$model->setState('filter.author_id.include', false);
				break;

			case '0':
				break;

			default:
				$model->setState('filter.author_id', (int) $params->get('user_id'));
				break;
		}		

		//  Featured switch
		switch ($params->get('show_featured'))
		{
			case '1':
				$model->setState('filter.featured', 'only');
				break;
			case '0':
				$model->setState('filter.featured', 'hide');
				break;
			default:
				$model->setState('filter.featured', 'show');
				break;
		}
		
		$model->setState('list.select', 'a.fulltext, a.id, a.title, a.alias, a.title_alias, a.introtext, a.state, a.catid, a.created, a.created_by, a.created_by_alias,' .
			' a.modified, a.modified_by,a.publish_up, a.publish_down, a.attribs, a.metadata, a.metakey, a.metadesc, a.access,' .
			' a.hits, a.featured,' .
			' LENGTH(a.fulltext) AS readmore');
			
		// Access filter
		$access = !JComponentHelper::getParams('com_content')->get('show_noauth');
		$authorised = JAccess::getAuthorisedViewLevels(JFactory::getUser()->get('id'));
		$model->setState('filter.access', $access);

		// Category filter
		$model->setState('filter.category_id', $params->get('catid', array()));

		// Filter by language
		$model->setState('filter.language',$app->getLanguageFilter());

		// Set ordering
		$model->setState('list.ordering', $params->get('ordering', 'a.ordering'));
		$model->setState('list.direction', $params->get('ordering_direction', 'ASC'));

		//	Retrieve Content
		$items = $model->getItems();
		
		foreach ($items as &$item) {
			$item->slug = $item->id.':'.$item->alias;
			$item->catslug 		= $item->catid.':'.$item->category_alias;
			$author 			= &JFactory::getUser($item->created_by);
			
			$item->author 		= $author->name;	
			$item->created 		= $item->created;
			$item->hits 		= $item->hits;
			
			$item->image 		= modNSSP1Helper::getImages($item->introtext,$thumbwidth,$thumbheight,$thumbratio,$uniqid)->image;
			$item->title 		= modNSSP1Helper::prepareTitle($item->title,$params );
			$item->introtext 	= modNSSP1Helper::prepareContent(JHtml::_('content.prepare', $item->introtext),$params);
			$item->link 		= JRoute::_(ContentHelperRoute::getArticleRoute($item->slug, $item->catslug));
		}	
		
		return $items;
		
	}		
	
	function prepareTitle($text, $params) {
		$text=htmlspecialchars($text);
		// Title limit
		$titlelimit=$params->get('titlelimit',20);
		switch ($params->get('titleas')) {
			case 0 :
				$text = explode(' ',$text);
				$sep = (count($text)>$titlelimit) ? '...' : '';
				$text=implode(' ', array_slice($text,0,$titlelimit)) . $sep;
				break;
			case 1 :
				$sep = (strlen($text)>$titlelimit) ? '...' : '';
				$text=utf8_substr($text,0,$titlelimit) . $sep;
				break;
			case 2 :
				$text = $text;
				break;
			default :
				$text = explode(' ',$text);
				$sep = (count($text)>$titlelimit) ? '...' : '';
				$text=implode(' ', array_slice($text,0,$titlelimit)) . $sep;
				break;				
		}		
		
		return $text;
	}	
	
	function prepareContent($text, $params) {
		
		$text = JFilterOutPut::cleanText($text);

	    // Description limit
		$desclimit=$params->get('desclimit',30);
		switch ($params->get('desclimitas')) {
			case 0 :
				$text = explode(' ',$text);
				$sep = (count($text)>$desclimit) ? '...' : '';
				$text=implode(' ', array_slice($text,0,$desclimit)) . $sep;
				break;
			case 1 :
				$sep = (strlen($text)>$desclimit) ? '...' : '';
				$text=utf8_substr($text,0,$desclimit) . $sep;
				break;
			case 2 :
				$text = $text;
				break;
			default :
				$text = explode(' ',$text);
				$sep = (count($text)>$desclimit) ? '...' : '';
				$text=implode(' ', array_slice($text,0,$desclimit)) . $sep;
				break;
		}		
		
		return $text;
	}
	
	
	function getImages($text, $thumbwidth=50, $thumbheight=50, $thumbratio, $uniqid) {

		preg_match('/< *img[^>]*src *= *["\']?([^"\']*)/i', $text, $matches);
		
		$images = new stdClass();
		$images->image = false;
		
		$paths = array();
		if (isset($matches[1])) {
			$image_path = $matches[1];
			
			// remove any / that begins the path
			if (substr($image_path, 0 , 1) == '/') $image_path = substr($image_path, 1);
			
			// create a thumb filename
			$file_div = strrpos($image_path,'.');
			$thumb_ext = substr($image_path, $file_div);
			$thumb_prev = substr($image_path, 0, $file_div);
			$thumb_path = $thumb_prev . "_thumb" . $uniqid . $thumb_ext;
				
			// check to see if this file exists, if so we don't need to create it
			if (function_exists("gd_info")) {
				// file doens't exist, so create it and save it
				if (!class_exists("spThumbnail")) include_once('class.spThumbnail.php');
				
				//Check existing thumbnails dimensions
				if (file_exists($thumb_path)) {
					$size = GetImageSize( $thumb_path );
					$currentWidth=$size[0];
					$currentHeight=$size[1];
				}
				
				//Creating thumbnails		
                if (!file_exists($thumb_path) || $currentWidth!=$thumbwidth || $currentHeight!=$thumbheight ) {
					$thumb = new spThumbnail;
					$thumb->new_width = $thumbwidth;
					$thumb->new_height = $thumbheight;
					$thumb->image_to_resize = $image_path; // Full Path to the file
					$thumb->ratio = $thumbratio; // Keep Aspect Ratio?
					$thumb->save = $thumb_path;
					$process = $thumb->resize();
    			}
			}
			
			$images->image = $thumb_path;
		} 
		return $images;
	}
}
 